VERSION 5.00
Begin VB.UserControl T_MoveButton 
   BackColor       =   &H00FF0000&
   BackStyle       =   0  'Transparent
   ClientHeight    =   690
   ClientLeft      =   0
   ClientTop       =   0
   ClientWidth     =   735
   ClipBehavior    =   0  'None
   HitBehavior     =   2  'Use Paint
   MousePointer    =   15  'Size All
   ScaleHeight     =   690
   ScaleWidth      =   735
   ToolboxBitmap   =   "T_MoveButton.ctx":0000
   Windowless      =   -1  'True
   Begin VB.Image btnImage 
      Height          =   720
      Index           =   1
      Left            =   0
      Picture         =   "T_MoveButton.ctx":0312
      Top             =   0
      Width           =   720
   End
   Begin VB.Image btnImage 
      Height          =   720
      Index           =   0
      Left            =   0
      Picture         =   "T_MoveButton.ctx":11DC
      Top             =   0
      Width           =   720
   End
End
Attribute VB_Name = "T_MoveButton"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
'---------------------------------------------------------------------------------------
' Module    : T_MoveButton
' DateTime  : 06/12/2004 14:04
' Author    : Steve Hunt - steve@huntnet.co.uk
' Purpose   : Simple Windowless User Control to allow moving of forms when
'             grabing the Titlebar is not Easy/Possible.  e.g. when form is borderless
'             or when using Touchscreen PC and Title bar is too small for user fingers.
'
'---------------------------------------------------------------------------------------
Option Explicit

Private btnState As Boolean
Private Owner As Object
Private DragStartX As Single
Private DragStartY As Single
Private FormStartX As Single
Private FormStartY As Single


'---------------------------------------------------------------------------------------
' Procedure : UserControl_Initialize
' DateTime  : 06/12/2004 14:08
' Author    : Steve Hunt
' Purpose   : Initialise the control to the size of the contained image.
'             Set up Clip Behavior and HitTest Behavior
'
' NOTE: ClipBehavior must be 0-None and HitBehavior must be 2 - UsePaint
'       Otherwise the HitTest event must be handled to see if the User control
'       can receive mouse input.  This can potentially take up a lot of System
'       resources, thus negating the advantage of a windowless control.
'---------------------------------------------------------------------------------------
Private Sub UserControl_Initialize()
    UserControl.Width = btnImage(0).Width
    UserControl.Height = btnImage(0).Height
    UserControl.ClipBehavior = 0
    UserControl.HitBehavior = 2
    btnState = False
    SetImages
End Sub

'---------------------------------------------------------------------------------------
' Procedure : UserControl_Resize
' DateTime  : 06/12/2004 14:11
' Author    : Steve Hunt
' Purpose   : Handle resizing of the control by not allowing a change in size.
'             This is a personal preference because I happen to think that the Button Images
'             would look pretty Naff if they were to be stretched during resizing.
'             If you would prefer to allow resizing of the control, change this procedure so
'             that btnImage(0) and btnImage(1) width and height properties match those of the user control.
'---------------------------------------------------------------------------------------
Private Sub UserControl_Resize()
    UserControl.Width = btnImage(0).Width
    UserControl.Height = btnImage(0).Height
End Sub

'---------------------------------------------------------------------------------------
' Procedure : UserControl_Show
' DateTime  : 06/12/2004 14:15
' Author    : Steve Hunt
' Purpose   : Here I have used the Ambient Object to determine in what mode the user
'             control is being shown.  During Design time, the control does not need
'             to do anything except look pretty, so there is no need to create the link
'             to the form that owns it.  Indeed, if the link were to be attempted during
'             design time, a "Client site unavailable" error would be generated.
'             I have used the run-time show event as the point at which to create the
'             link because this will ensure that the form has been generated before trying
'             to link to it.
'
'             NB: The Ambient.UserMode Property is TRUE at Run-time and FALSE during Design Time
'---------------------------------------------------------------------------------------
Private Sub UserControl_Show()
    If Ambient.UserMode = True Then Set Owner = UserControl.Parent
    End Sub

'---------------------------------------------------------------------------------------
' Procedure : btnImage_MouseDown
' DateTime  : 06/12/2004 14:21
' Author    : Steve Hunt
' Purpose   : Begin the Drag process IF the control is pressed during runtime and change
'             the button image to appear "Pressed".  Make a note of where the Form and Cursor
'             Locations at the beginning of the Drag Process.
'---------------------------------------------------------------------------------------

Private Sub btnImage_MouseDown(Index As Integer, Button As Integer, Shift As Integer, X As Single, Y As Single)
    If Ambient.UserMode = True Then
       If Button = 1 And btnState = False Then ' Left Button
           FormStartX = Owner.Left
           FormStartY = Owner.Top
           DragStartX = FormStartX + X
           DragStartY = FormStartY + Y
       End If
    End If
   btnState = True
   SetImages
End Sub

'---------------------------------------------------------------------------------------
' Procedure : btnImage_MouseMove
' DateTime  : 06/12/2004 14:26
' Author    : Steve Hunt
' Purpose   : Reposition the Owner Form based on the new Cursor location
'---------------------------------------------------------------------------------------
Private Sub btnImage_MouseMove(Index As Integer, Button As Integer, Shift As Integer, X As Single, Y As Single)
   'Place holder
    If Button = 1 And btnState = True Then ' Left Button and Already Dragging
        Owner.Left = FormStartX + ((Owner.Left + X) - DragStartX)
        Owner.Top = FormStartY + ((Owner.Top + Y) - DragStartY)
    End If
End Sub

'---------------------------------------------------------------------------------------
' Procedure : btnImage_MouseUp
' DateTime  : 06/12/2004 14:27
' Author    : Steve Hunt
' Purpose   : End the Drag process and change the button image to appear "UnPressed"
'---------------------------------------------------------------------------------------
Private Sub btnImage_MouseUp(Index As Integer, Button As Integer, Shift As Integer, X As Single, Y As Single)
   btnState = False
   SetImages
End Sub


'---------------------------------------------------------------------------------------
' Procedure : SetImages
' DateTime  : 06/12/2004 14:28
' Author    : Steve Hunt
' Purpose   : Sorts out the visual component of the Control.
'             If the control is "Pressed" (btnState = True) then btnImage(1) should be visible
'             otherwise btnImage(0) should be visible
'---------------------------------------------------------------------------------------
Private Sub SetImages()
    Select Case btnState
        Case True
            btnImage(0).Visible = False
            btnImage(1).Visible = True
        Case False
            btnImage(0).Visible = True
            btnImage(1).Visible = False
    End Select
End Sub

